@@ -24,15 +24,21 @@
 #define __PREFWIN_H__
 
 typedef struct prefwin_widgets_ {
-  GtkWidget *menu_uid, *menu_gid, *home;
-  GtkWidget *hbox_tip, *btn_create_id;
-  GtkWidget *cmd_purepw, *pwfile, *pdbfile;
-  GtkWidget *btn_search, *chk_resolve, *btn_home_browse;
-  GtkWidget *rdo_syslog, *rdo_custom, *logfile;
+	GtkWidget *menu_uid, *menu_gid, *home, *encoding;
+	GtkWidget *hbox_tip, *btn_create_id;
+	GtkWidget *cmd_purepw, *pwfile, *pdbfile;
+	GtkWidget *btn_search, *chk_resolve, *btn_home_browse, *btn_encoding_sel;
+	GtkWidget *btn_browse_purepw, *btn_browse_pw, *btn_browse_pdb;
+	GtkWidget *rdo_syslog, *rdo_custom, *logfile;
+	GtkWidget *chk_save_window_geo, *chk_use_system_encoding;
+	GtkWidget *chk_use_tray_icon;
 } prefwin_widgets;
 
-extern GtkWidget *prefwin;
+typedef struct pa_encoding_t_ {
+  gchar *realname;
+  gchar *label;
+} pa_encoding_t;
 
-void pref_init_prefwindow (GtkWidget *dlg);
+GtkWidget *pref_init_prefwindow (GtkWidget *parent);
 
 #endif /* __PREFWIN_H__ */
